@@ -4,8 +4,9 @@ import requests
 
 class DownloadResourcesAction(IAction):
 
-    def __init__(self, name, target_version, config: LennyBotActionConfig) -> None:
+    def __init__(self, name, source_version, target_version, config: LennyBotActionConfig) -> None:
         self._name = name
+        self._source_version = source_version
         self._target_version = target_version
         self._url = config.url
         self._target_path = config.target
@@ -14,6 +15,10 @@ class DownloadResourcesAction(IAction):
     def application(self) -> str:
         return self._name
 
+    @property
+    def source_version(self) -> str:
+        return self._source_version
+
     @property
     def target_version(self) -> str:
         return self._target_version
@@ -24,4 +29,4 @@ class DownloadResourcesAction(IAction):
         if response.status_code != 200:
             raise Exception("Unable to download resources")
         with open(self._target_path, "w") as file_ptr:
-            file_ptr.write(response.text)upd
\ No newline at end of file
+            file_ptr.write(response.text)
\ No newline at end of file
